==> deepin-compressor-debug-5.12.23-2-x86_64.pkg.tar.zst: usr/src/debug/deepin-compressor/deepin-compressor-5.12.23/src/qrc_config.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.12
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-compressor/src/deepin-compressor-5.12.23/src/assets/data/deepin-compressor.json
  0x0,0x0,0x3,0x35,
  0x0,
  0x0,0x2b,0xee,0x78,0x9c,0xcd,0x9a,0x5d,0x6f,0x9b,0x30,0x14,0x86,0xef,0xf3,0x2b,
  0xac,0x5c,0x79,0xd2,0x88,0xa6,0x6e,0x6a,0xb5,0xdd,0x55,0xda,0xba,0xab,0x5d,0x75,
  0x57,0x9b,0xaa,0xc8,0x38,0x4e,0x42,0xb,0x18,0xd9,0x26,0x75,0xa8,0xfa,0xdf,0x67,
  0x3b,0x24,0x69,0xf8,0x48,0xd0,0xd6,0x2e,0x2f,0x52,0x20,0xd8,0x7,0xf3,0xfa,0xe1,
  0x9c,0x63,0x63,0xf1,0x34,0x22,0x6e,0x1b,0x2f,0x94,0x2c,0xb,0x3d,0xfe,0x42,0x7e,
  0x87,0x73,0xbf,0x3d,0xed,0xfe,0x5,0x8b,0x7,0xb1,0x76,0xd5,0xe3,0x98,0x69,0x31,
  0x7e,0x7f,0x58,0x95,0xb3,0x4c,0xf8,0xba,0xef,0x22,0x17,0x8a,0xa5,0xcd,0xea,0x8e,
  0xb6,0xbb,0xef,0xd1,0xbc,0xd7,0x4c,0x70,0x99,0x15,0x4a,0x68,0xdd,0x68,0xb2,0x75,
  0xe7,0x6f,0xd6,0x28,0xc6,0x4d,0x22,0xf3,0x3e,0x4b,0x59,0xf8,0xda,0x6e,0x15,0xc7,
  0xd5,0xb4,0x55,0xcd,0x59,0x99,0x9a,0x69,0xc1,0xcc,0xb2,0xe7,0x6e,0xbb,0x4b,0xcc,
  0xba,0x8,0xfa,0xbc,0x6d,0x2c,0xed,0x29,0xf3,0xba,0x69,0x7f,0xc5,0xb8,0xd7,0xf2,
  0xb9,0xbf,0x91,0x61,0x1d,0xe0,0x4a,0x30,0x23,0xa6,0x73,0x99,0xce,0x84,0x3a,0x25,
  0x69,0x4b,0x98,0xc,0xed,0x2a,0x5f,0xa,0xfe,0x30,0xa0,0xaf,0x46,0xd8,0xd0,0xd1,
  0xeb,0xd2,0x48,0xb2,0x91,0x44,0x18,0xd9,0x88,0x72,0x7,0x45,0x32,0x47,0x22,0x29,
  0x52,0x41,0xc4,0xe6,0xe1,0x8a,0x19,0x99,0x27,0xa9,0xe8,0xf3,0x85,0x5d,0xc3,0x7b,
  0x88,0x46,0x95,0xe2,0xed,0x30,0xca,0x42,0xe4,0x28,0x10,0x6f,0x97,0xf2,0xb1,0xc9,
  0x89,0x3c,0x2e,0x45,0x4e,0x7c,0x4,0xa5,0xc2,0x15,0xe,0xc7,0x36,0x67,0xa9,0x3e,
  0xc2,0xad,0xb3,0xe6,0xae,0x55,0xda,0xc1,0xf7,0x78,0xb4,0x7b,0xd1,0xd3,0x8c,0xe5,
  0x6c,0x21,0x32,0x91,0x9b,0x53,0x21,0x7f,0xe3,0xcc,0xc9,0x8f,0x93,0xe6,0xaf,0x19,
  0xf7,0x9e,0xe3,0x74,0x9b,0x92,0xc4,0x6c,0xea,0x15,0xf,0x7d,0xa2,0x9b,0xab,0x61,
  0x72,0x40,0xdd,0x99,0x21,0x3d,0x78,0x73,0xe7,0xfd,0x1a,0xb4,0xd4,0x4e,0xcb,0xe6,
  0xc6,0xc5,0xff,0x16,0x72,0x7f,0x42,0xdf,0xb5,0xf2,0xaf,0x7e,0xdb,0x76,0xdc,0xd1,
  0xa1,0xc1,0xae,0x7c,0x2f,0xa4,0x7b,0x68,0xc,0xe,0xcc,0xb4,0x96,0x3c,0x61,0x1d,
  0x43,0xd1,0x81,0xe7,0x6a,0x72,0x5d,0x1b,0xb6,0x22,0xf3,0xef,0xc7,0xcb,0xa6,0x80,
  0x69,0x78,0x22,0x43,0xe2,0xe8,0xe7,0x11,0xc3,0xd7,0x8b,0x20,0x1b,0x5d,0x55,0xd1,
  0x3e,0x7e,0xce,0xee,0x78,0xd,0x3d,0xf4,0xaa,0x7a,0x87,0x32,0xb8,0xd8,0x88,0x29,
  0xbe,0x4c,0x56,0xe7,0x8f,0xce,0x9d,0x12,0xca,0x80,0xe8,0xc4,0xbc,0x48,0x24,0x0,
  0x9b,0xa0,0x83,0x86,0x3d,0x12,0x9d,0x2a,0x29,0x10,0xe0,0x38,0x19,0x34,0xae,0x2e,
  0x80,0xc8,0x80,0xb8,0x4d,0xf0,0x1a,0x30,0xa7,0xf1,0x72,0xb0,0xb2,0x73,0x43,0x51,
  0x0,0x36,0x59,0xe0,0x24,0xe9,0x55,0x3e,0x9b,0xcc,0x44,0x9c,0xb0,0x7c,0x12,0x27,
  0x39,0x53,0xeb,0xa8,0x60,0xfc,0xc1,0x4d,0x48,0xcf,0xce,0xae,0x57,0x19,0x75,0xa5,
  0x30,0xfc,0x16,0x8,0x69,0xca,0x8b,0xa0,0x40,0x4e,0x65,0xa3,0x7b,0xb6,0x62,0x40,
  0xc3,0xff,0x4b,0x39,0xf4,0x9e,0x29,0x20,0x52,0x69,0x95,0x31,0x0,0x42,0x5e,0x6,
  0xf5,0x3b,0x18,0x34,0x3e,0xfe,0x33,0x1d,0x71,0x16,0x23,0x65,0xf4,0x4e,0x55,0xd4,
  0x9d,0x42,0x71,0x53,0xec,0xfc,0xeb,0x39,0xb5,0xe,0xaa,0xa0,0xc2,0x4d,0x15,0xd9,
  0xd9,0xc9,0x4,0x15,0xd4,0xfd,0x80,0xb8,0xe8,0xd5,0x27,0x90,0x79,0x65,0xad,0x84,
  0xd6,0x47,0x30,0x46,0x8a,0x83,0x20,0x52,0x9c,0x6e,0xe,0x40,0x80,0xc,0x40,0xda,
  0x9,0x2a,0xa8,0x81,0x4a,0x3a,0xfe,0x25,0xf2,0xc5,0x70,0x1,0xc2,0xa9,0x43,0x95,
  0xe7,0x36,0x1,0x7b,0xdb,0x45,0xc3,0xd6,0x41,0xc,0x6a,0xea,0x9d,0x42,0x3a,0x5b,
  0x87,0xaa,0x80,0x2e,0xc5,0x42,0x97,0x31,0x44,0x74,0x2d,0x55,0x35,0x3a,0xa0,0xd9,
  0xba,0x4b,0xbb,0x15,0xc2,0xec,0xc1,0xa9,0xa8,0xe1,0x20,0xcd,0x1c,0x6c,0x85,0xe7,
  0x56,0x2d,0x4d,0x81,0x9b,0x45,0x8a,0x47,0x27,0xa8,0x2,0x20,0xe5,0x65,0x4,0x38,
  0xbf,0x80,0xd8,0x58,0xc,0x27,0x72,0x6e,0x63,0xa1,0xe6,0x5a,0x16,0xc1,0x63,0x6c,
  0x45,0x81,0x2,0x9,0x61,0x89,0xd2,0xaf,0x50,0xba,0x1f,0xc,0x13,0x1b,0x25,0x5a,
  0x7e,0xbe,0xbc,0xfc,0x10,0x25,0x19,0xc2,0x6a,0x77,0x43,0xf,0x75,0x67,0x80,0xac,
  0x58,0x51,0xa0,0xe1,0xda,0x4a,0xa2,0xdb,0x3f,0x40,0xd8,0xb4,0x2c,0x15,0x17,0x20,
  0x6b,0x4e,0x7b,0x31,0x54,0x2b,0x3e,0xc1,0x5a,0x7e,0xe2,0x4b,0x25,0x33,0x11,0x39,
  0xb1,0x22,0x1f,0xf2,0xc5,0xcc,0xff,0x78,0xcf,0x6b,0x48,0xa2,0x5c,0x59,0x18,0x62,
  0xda,0xac,0x87,0x7f,0xf5,0x74,0x23,0x73,0x43,0x6e,0x87,0x5c,0xb1,0xa3,0x55,0x6a,
  0x23,0xb3,0x28,0x2e,0x8d,0x39,0xfd,0x2c,0xb6,0xc8,0x2e,0x2e,0x3e,0x1e,0xf9,0xda,
  0xab,0xb3,0xa6,0xe3,0x93,0xbb,0x51,0x77,0xfd,0xa6,0xfc,0x6e,0xf4,0x3c,0xfa,0x3,
  0xc2,0xfa,0x54,0x48,
  
};

static const unsigned char qt_resource_name[] = {
  // assets
  0x0,0x6,
  0x6,0x8a,0x9c,0xb3,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,
    // data
  0x0,0x4,
  0x0,0x6,0xa8,0xa1,
  0x0,0x64,
  0x0,0x61,0x0,0x74,0x0,0x61,
    // deepin-compressor.json
  0x0,0x16,
  0x2,0x95,0x4c,0xbe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,0x6f,0x0,0x72,
  0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8d,0xa2,0xf9,0xb3,0xd0,
  // :/assets
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8d,0xa2,0xf9,0xb3,0xd0,
  // :/assets/data
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x8d,0xa2,0xf9,0xb3,0xd0,
  // :/assets/data/deepin-compressor.json
  0x0,0x0,0x0,0x20,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8d,0xa2,0xf9,0xb3,0xd0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_config)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)(); }
   } dummy;
}

==> deepin-compressor-debug-5.12.23-3-x86_64.pkg.tar.zst: usr/src/debug/deepin-compressor/deepin-compressor-5.12.23/src/qrc_config.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.13
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-compressor/src/deepin-compressor-5.12.23/src/assets/data/deepin-compressor.json
  0x0,0x0,0x3,0x35,
  0x0,
  0x0,0x2b,0xee,0x78,0x9c,0xcd,0x9a,0x5d,0x6f,0x9b,0x30,0x14,0x86,0xef,0xf3,0x2b,
  0xac,0x5c,0x79,0xd2,0x88,0xa6,0x6e,0x6a,0xb5,0xdd,0x55,0xda,0xba,0xab,0x5d,0x75,
  0x57,0x9b,0xaa,0xc8,0x38,0x4e,0x42,0xb,0x18,0xd9,0x26,0x75,0xa8,0xfa,0xdf,0x67,
  0x3b,0x24,0x69,0xf8,0x48,0xd0,0xd6,0x2e,0x2f,0x52,0x20,0xd8,0x7,0xf3,0xfa,0xe1,
  0x9c,0x63,0x63,0xf1,0x34,0x22,0x6e,0x1b,0x2f,0x94,0x2c,0xb,0x3d,0xfe,0x42,0x7e,
  0x87,0x73,0xbf,0x3d,0xed,0xfe,0x5,0x8b,0x7,0xb1,0x76,0xd5,0xe3,0x98,0x69,0x31,
  0x7e,0x7f,0x58,0x95,0xb3,0x4c,0xf8,0xba,0xef,0x22,0x17,0x8a,0xa5,0xcd,0xea,0x8e,
  0xb6,0xbb,0xef,0xd1,0xbc,0xd7,0x4c,0x70,0x99,0x15,0x4a,0x68,0xdd,0x68,0xb2,0x75,
  0xe7,0x6f,0xd6,0x28,0xc6,0x4d,0x22,0xf3,0x3e,0x4b,0x59,0xf8,0xda,0x6e,0x15,0xc7,
  0xd5,0xb4,0x55,0xcd,0x59,0x99,0x9a,0x69,0xc1,0xcc,0xb2,0xe7,0x6e,0xbb,0x4b,0xcc,
  0xba,0x8,0xfa,0xbc,0x6d,0x2c,0xed,0x29,0xf3,0xba,0x69,0x7f,0xc5,0xb8,0xd7,0xf2,
  0xb9,0xbf,0x91,0x61,0x1d,0xe0,0x4a,0x30,0x23,0xa6,0x73,0x99,0xce,0x84,0x3a,0x25,
  0x69,0x4b,0x98,0xc,0xed,0x2a,0x5f,0xa,0xfe,0x30,0xa0,0xaf,0x46,0xd8,0xd0,0xd1,
  0xeb,0xd2,0x48,0xb2,0x91,0x44,0x18,0xd9,0x88,0x72,0x7,0x45,0x32,0x47,0x22,0x29,
  0x52,0x41,0xc4,0xe6,0xe1,0x8a,0x19,0x99,0x27,0xa9,0xe8,0xf3,0x85,0x5d,0xc3,0x7b,
  0x88,0x46,0x95,0xe2,0xed,0x30,0xca,0x42,0xe4,0x28,0x10,0x6f,0x97,0xf2,0xb1,0xc9,
  0x89,0x3c,0x2e,0x45,0x4e,0x7c,0x4,0xa5,0xc2,0x15,0xe,0xc7,0x36,0x67,0xa9,0x3e,
  0xc2,0xad,0xb3,0xe6,0xae,0x55,0xda,0xc1,0xf7,0x78,0xb4,0x7b,0xd1,0xd3,0x8c,0xe5,
  0x6c,0x21,0x32,0x91,0x9b,0x53,0x21,0x7f,0xe3,0xcc,0xc9,0x8f,0x93,0xe6,0xaf,0x19,
  0xf7,0x9e,0xe3,0x74,0x9b,0x92,0xc4,0x6c,0xea,0x15,0xf,0x7d,0xa2,0x9b,0xab,0x61,
  0x72,0x40,0xdd,0x99,0x21,0x3d,0x78,0x73,0xe7,0xfd,0x1a,0xb4,0xd4,0x4e,0xcb,0xe6,
  0xc6,0xc5,0xff,0x16,0x72,0x7f,0x42,0xdf,0xb5,0xf2,0xaf,0x7e,0xdb,0x76,0xdc,0xd1,
  0xa1,0xc1,0xae,0x7c,0x2f,0xa4,0x7b,0x68,0xc,0xe,0xcc,0xb4,0x96,0x3c,0x61,0x1d,
  0x43,0xd1,0x81,0xe7,0x6a,0x72,0x5d,0x1b,0xb6,0x22,0xf3,0xef,0xc7,0xcb,0xa6,0x80,
  0x69,0x78,0x22,0x43,0xe2,0xe8,0xe7,0x11,0xc3,0xd7,0x8b,0x20,0x1b,0x5d,0x55,0xd1,
  0x3e,0x7e,0xce,0xee,0x78,0xd,0x3d,0xf4,0xaa,0x7a,0x87,0x32,0xb8,0xd8,0x88,0x29,
  0xbe,0x4c,0x56,0xe7,0x8f,0xce,0x9d,0x12,0xca,0x80,0xe8,0xc4,0xbc,0x48,0x24,0x0,
  0x9b,0xa0,0x83,0x86,0x3d,0x12,0x9d,0x2a,0x29,0x10,0xe0,0x38,0x19,0x34,0xae,0x2e,
  0x80,0xc8,0x80,0xb8,0x4d,0xf0,0x1a,0x30,0xa7,0xf1,0x72,0xb0,0xb2,0x73,0x43,0x51,
  0x0,0x36,0x59,0xe0,0x24,0xe9,0x55,0x3e,0x9b,0xcc,0x44,0x9c,0xb0,0x7c,0x12,0x27,
  0x39,0x53,0xeb,0xa8,0x60,0xfc,0xc1,0x4d,0x48,0xcf,0xce,0xae,0x57,0x19,0x75,0xa5,
  0x30,0xfc,0x16,0x8,0x69,0xca,0x8b,0xa0,0x40,0x4e,0x65,0xa3,0x7b,0xb6,0x62,0x40,
  0xc3,0xff,0x4b,0x39,0xf4,0x9e,0x29,0x20,0x52,0x69,0x95,0x31,0x0,0x42,0x5e,0x6,
  0xf5,0x3b,0x18,0x34,0x3e,0xfe,0x33,0x1d,0x71,0x16,0x23,0x65,0xf4,0x4e,0x55,0xd4,
  0x9d,0x42,0x71,0x53,0xec,0xfc,0xeb,0x39,0xb5,0xe,0xaa,0xa0,0xc2,0x4d,0x15,0xd9,
  0xd9,0xc9,0x4,0x15,0xd4,0xfd,0x80,0xb8,0xe8,0xd5,0x27,0x90,0x79,0x65,0xad,0x84,
  0xd6,0x47,0x30,0x46,0x8a,0x83,0x20,0x52,0x9c,0x6e,0xe,0x40,0x80,0xc,0x40,0xda,
  0x9,0x2a,0xa8,0x81,0x4a,0x3a,0xfe,0x25,0xf2,0xc5,0x70,0x1,0xc2,0xa9,0x43,0x95,
  0xe7,0x36,0x1,0x7b,0xdb,0x45,0xc3,0xd6,0x41,0xc,0x6a,0xea,0x9d,0x42,0x3a,0x5b,
  0x87,0xaa,0x80,0x2e,0xc5,0x42,0x97,0x31,0x44,0x74,0x2d,0x55,0x35,0x3a,0xa0,0xd9,
  0xba,0x4b,0xbb,0x15,0xc2,0xec,0xc1,0xa9,0xa8,0xe1,0x20,0xcd,0x1c,0x6c,0x85,0xe7,
  0x56,0x2d,0x4d,0x81,0x9b,0x45,0x8a,0x47,0x27,0xa8,0x2,0x20,0xe5,0x65,0x4,0x38,
  0xbf,0x80,0xd8,0x58,0xc,0x27,0x72,0x6e,0x63,0xa1,0xe6,0x5a,0x16,0xc1,0x63,0x6c,
  0x45,0x81,0x2,0x9,0x61,0x89,0xd2,0xaf,0x50,0xba,0x1f,0xc,0x13,0x1b,0x25,0x5a,
  0x7e,0xbe,0xbc,0xfc,0x10,0x25,0x19,0xc2,0x6a,0x77,0x43,0xf,0x75,0x67,0x80,0xac,
  0x58,0x51,0xa0,0xe1,0xda,0x4a,0xa2,0xdb,0x3f,0x40,0xd8,0xb4,0x2c,0x15,0x17,0x20,
  0x6b,0x4e,0x7b,0x31,0x54,0x2b,0x3e,0xc1,0x5a,0x7e,0xe2,0x4b,0x25,0x33,0x11,0x39,
  0xb1,0x22,0x1f,0xf2,0xc5,0xcc,0xff,0x78,0xcf,0x6b,0x48,0xa2,0x5c,0x59,0x18,0x62,
  0xda,0xac,0x87,0x7f,0xf5,0x74,0x23,0x73,0x43,0x6e,0x87,0x5c,0xb1,0xa3,0x55,0x6a,
  0x23,0xb3,0x28,0x2e,0x8d,0x39,0xfd,0x2c,0xb6,0xc8,0x2e,0x2e,0x3e,0x1e,0xf9,0xda,
  0xab,0xb3,0xa6,0xe3,0x93,0xbb,0x51,0x77,0xfd,0xa6,0xfc,0x6e,0xf4,0x3c,0xfa,0x3,
  0xc2,0xfa,0x54,0x48,
  
};

static const unsigned char qt_resource_name[] = {
  // assets
  0x0,0x6,
  0x6,0x8a,0x9c,0xb3,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,
    // data
  0x0,0x4,
  0x0,0x6,0xa8,0xa1,
  0x0,0x64,
  0x0,0x61,0x0,0x74,0x0,0x61,
    // deepin-compressor.json
  0x0,0x16,
  0x2,0x95,0x4c,0xbe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,0x6f,0x0,0x72,
  0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8e,0x3d,0x2a,0xd1,0x0,
  // :/assets
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8e,0x3d,0x2a,0xd1,0x0,
  // :/assets/data
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x8e,0x3d,0x2a,0xd1,0x0,
  // :/assets/data/deepin-compressor.json
  0x0,0x0,0x0,0x20,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8e,0x3d,0x2a,0xd1,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_config)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)(); }
   } dummy;
}
